@@ -1,13 +1,13 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
-import feedparser
+import csv
 import re
 from cgi import parse_header
 
 from flexget import plugin
 from flexget.event import event
 from flexget.utils import requests
-from flexget.utils.imdb import make_url, extract_id
+from flexget.utils.imdb import make_url
 from flexget.utils.cached_input import cached
 from flexget.utils.tools import decode_html
 from flexget.entry import Entry
@@ -33,7 +33,7 @@ class ImdbList(object):
             'password': {'type': 'string'},
             'list': {'type': 'string'}
         },
-        'required': ['list'],
+        'required': ['list', 'username', 'password'],
         'additionalProperties': False
     }
 
@@ -88,27 +88,32 @@ class ImdbList(object):
 
         log.verbose('Retrieving list %s ...' % config['list'])
 
-        # Get the imdb list in RSS format
+        # Get the imdb list in csv format
         try:
-            if config['list'] in ['watchlist', 'ratings', 'checkins']:
-                url = 'http://rss.imdb.com/user/%s/%s' % (config['user_id'], config['list'])
-            else:
-                url = 'http://rss.imdb.com/list/%s' % config['list']
+            url = 'http://www.imdb.com/list/export'
+            params = {'list_id': config['list'], 'author_id': config['user_id']}
             log.debug('Requesting %s' % url)
-            try:
-                rss = feedparser.parse(url)
-            except LookupError as e:
-                raise plugin.PluginError('Failed to parse RSS feed for list `%s` correctly: %s' % (config['list'], e))
+            opener = sess.get(url, params=params)
+            mime_type = parse_header(opener.headers['content-type'])[0]
+            log.debug('mime_type: %s' % mime_type)
+            if mime_type != 'text/csv':
+                raise plugin.PluginError('Didn\'t get CSV export as response. Probably specified list `%s` '
+                                         'does not exist.' % config['list'])
+            csv_rows = csv.reader(opener.iter_lines())
         except requests.RequestException as e:
             raise plugin.PluginError('Unable to get imdb list: %s' % e.message)
 
         # Create an Entry for each movie in the list
         entries = []
-        for entry in rss.entries:
+        for row in csv_rows:
+            if not row or row[0] == 'position':
+                # Don't use blank rows or the headings row
+                continue
             try:
-                entries.append(Entry(title=entry.title, url=entry.link, imdb_id=extract_id(entry.link), imdb_name=entry.title))
+                title = decode_html(row[5]).decode('utf-8')
+                entries.append(Entry(title=title, url=make_url(row[1]), imdb_id=row[1], imdb_name=title))
             except IndexError:
-                log.critical('IndexError! Unable to handle RSS entry: %s' % entry)
+                log.critical('IndexError! Unable to handle row: %s' % row)
         return entries
 
 
